@@ -31,7 +31,7 @@ while [[ $# -gt 0 ]]; do
   esac
 done
 
-RUSTFLAGS='-D warnings' cargo build --target "$target" --release --verbose
+RUSTFLAGS='-D warnings -Zstack-protector=strong' cargo build --target "$target" --release --verbose
 
 binary_path="target/$target/release/kibi"
 
@@ -60,6 +60,8 @@ cp -R \
   README.md \
   config_example.ini \
   syntax.d \
+  assets/kibi.svg \
+  kibi.desktop \
   "$tmp_dir/$archive_dir"
 
 if [[ "$dest_path" == *.tar.gz ]]; then
