@@ -7,10 +7,10 @@ pub(crate) const USE_MAIN_SCREEN: &str = "\x1b[?1049l";
 pub(crate) const USE_ALTERNATE_SCREEN: &str = "\x1b[?1049h";
 
 /// Reset the formatting
-pub(crate) const RESET_FMT: &str = "\x1b[m";
+pub(crate) const RESET: &str = "\x1b[m";
 
-/// Invert foreground and background color
-pub(crate) const REVERSE_VIDEO: &str = "\x1b[7m";
+/// White background: invert foreground and background color
+pub(crate) const WBG: &str = "\x1b[7m";
 
 /// Move the cursor to 1:1
 pub(crate) const MOVE_CURSOR_TO_START: &str = "\x1b[H";
@@ -28,3 +28,9 @@ pub(crate) const DEVICE_STATUS_REPORT: &str = "\x1b[6n";
 
 /// Reposition the cursor to the end of the window
 pub(crate) const REPOSITION_CURSOR_END: &str = "\x1b[999C\x1b[999B";
+
+pub(crate) fn push_colored(buffer: &mut String, color: &str, message: &str, use_color: bool) {
+    for s in &[if use_color { color } else { "" }, message, if use_color { RESET } else { "" }] {
+        buffer.push_str(s);
+    }
+}
